==> odata-client-msgraph-beta-0.1.26-sources.jar: odata/msgraph/client/beta/complex/ExternalDomainFederation.java <==
package odata.msgraph.client.beta.complex;

import com.fasterxml.jackson.annotation.JacksonInject;
import com.fasterxml.jackson.annotation.JsonAnySetter;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonInclude.Include;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.github.davidmoten.odata.client.ODataType;
import com.github.davidmoten.odata.client.Util;
import com.github.davidmoten.odata.client.annotation.Property;
import com.github.davidmoten.odata.client.internal.ChangedFields;
import com.github.davidmoten.odata.client.internal.UnmappedFields;

import java.util.Optional;

@JsonPropertyOrder({
    "@odata.type", 
    "issuerUri", 
    "domainName", 
    "displayName"})
@JsonInclude(Include.NON_NULL)
public class ExternalDomainFederation extends IdentitySource implements ODataType {

    @JacksonInject
    @JsonIgnore
    protected UnmappedFields unmappedFields;

    @JsonProperty("issuerUri")
    protected String issuerUri;

    @JsonProperty("domainName")
    protected String domainName;

    @JsonProperty("displayName")
    protected String displayName;

    protected ExternalDomainFederation() {
        super();
    }

    @Override
    public String odataTypeName() {
        return "microsoft.graph.externalDomainFederation";
    }

    @Property(name="issuerUri")
    @JsonIgnore
    public Optional<String> getIssuerUri() {
        return Optional.ofNullable(issuerUri);
    }

    public ExternalDomainFederation withIssuerUri(String issuerUri) {
        ExternalDomainFederation _x = _copy();
        _x.odataType = Util.nvl(odataType, "microsoft.graph.externalDomainFederation");
        _x.issuerUri = issuerUri;
        return _x;
    }

    @Property(name="domainName")
    @JsonIgnore
    public Optional<String> getDomainName() {
        return Optional.ofNullable(domainName);
    }

    public ExternalDomainFederation withDomainName(String domainName) {
        ExternalDomainFederation _x = _copy();
        _x.odataType = Util.nvl(odataType, "microsoft.graph.externalDomainFederation");
        _x.domainName = domainName;
        return _x;
    }

    @Property(name="displayName")
    @JsonIgnore
    public Optional<String> getDisplayName() {
        return Optional.ofNullable(displayName);
    }

    public ExternalDomainFederation withDisplayName(String displayName) {
        ExternalDomainFederation _x = _copy();
        _x.odataType = Util.nvl(odataType, "microsoft.graph.externalDomainFederation");
        _x.displayName = displayName;
        return _x;
    }

    @JsonAnySetter
    private void setUnmappedField(String name, Object value) {
        if (unmappedFields == null) {
            unmappedFields = new UnmappedFields();
        }
        unmappedFields.put(name, value);
    }

    @Override
    @JsonIgnore
    public UnmappedFields getUnmappedFields() {
        return unmappedFields == null ? new UnmappedFields() : unmappedFields;
    }

    @Override
    public void postInject(boolean addKeysToContextPath) {
        // do nothing;
    }

    /**
     * Returns a builder which is used to create a new
     * instance of this class (given that this class is immutable).
     *
     * @return a new Builder for this class
     */
    // Suffix used on builder factory method to differentiate the method
    // from static builder methods on superclasses
    public static Builder builderExternalDomainFederation() {
        return new Builder();
    }

    public static final class Builder {
        private String issuerUri;
        private String domainName;
        private String displayName;
        private ChangedFields changedFields = new ChangedFields();

        Builder() {
            // prevent instantiation
        }

        public Builder issuerUri(String issuerUri) {
            this.issuerUri = issuerUri;
            this.changedFields = changedFields.add("issuerUri");
            return this;
        }

        public Builder domainName(String domainName) {
            this.domainName = domainName;
            this.changedFields = changedFields.add("domainName");
            return this;
        }

        public Builder displayName(String displayName) {
            this.displayName = displayName;
            this.changedFields = changedFields.add("displayName");
            return this;
        }

        public ExternalDomainFederation build() {
            ExternalDomainFederation _x = new ExternalDomainFederation();
            _x.contextPath = null;
            _x.unmappedFields = new UnmappedFields();
            _x.odataType = "microsoft.graph.externalDomainFederation";
            _x.issuerUri = issuerUri;
            _x.domainName = domainName;
            _x.displayName = displayName;
            return _x;
        }
    }

    private ExternalDomainFederation _copy() {
        ExternalDomainFederation _x = new ExternalDomainFederation();
        _x.contextPath = contextPath;
        _x.unmappedFields = unmappedFields;
        _x.odataType = odataType;
        _x.issuerUri = issuerUri;
        _x.domainName = domainName;
        _x.displayName = displayName;
        return _x;
    }

    @Override
    public String toString() {
        StringBuilder b = new StringBuilder();
        b.append("ExternalDomainFederation[");
        b.append("issuerUri=");
        b.append(this.issuerUri);
        b.append(", ");
        b.append("domainName=");
        b.append(this.domainName);
        b.append(", ");
        b.append("displayName=");
        b.append(this.displayName);
        b.append("]");
        b.append(",unmappedFields=");
        b.append(unmappedFields);
        b.append(",odataType=");
        b.append(odataType);
        return b.toString();
    }

}

==> odata-client-msgraph-beta-0.2.2-sources.jar: odata/msgraph/client/beta/complex/ExternalDomainFederation.java <==
package odata.msgraph.client.beta.complex;

import com.fasterxml.jackson.annotation.JsonAnyGetter;
import com.fasterxml.jackson.annotation.JsonAnySetter;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonInclude.Include;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.github.davidmoten.odata.client.ODataType;
import com.github.davidmoten.odata.client.UnmappedFields;
import com.github.davidmoten.odata.client.Util;
import com.github.davidmoten.odata.client.annotation.Property;
import com.github.davidmoten.odata.client.internal.ChangedFields;
import com.github.davidmoten.odata.client.internal.UnmappedFieldsImpl;

import java.lang.Object;
import java.lang.Override;
import java.lang.String;
import java.lang.StringBuilder;
import java.util.Optional;

@JsonPropertyOrder({
    "@odata.type", 
    "displayName", 
    "domainName", 
    "issuerUri"})
@JsonInclude(Include.NON_NULL)
public class ExternalDomainFederation extends IdentitySource implements ODataType {

    @JsonProperty("displayName")
    protected String displayName;

    @JsonProperty("domainName")
    protected String domainName;

    @JsonProperty("issuerUri")
    protected String issuerUri;

    protected ExternalDomainFederation() {
        super();
    }

    @Override
    public String odataTypeName() {
        return "microsoft.graph.externalDomainFederation";
    }

    @Property(name="displayName")
    @JsonIgnore
    public Optional<String> getDisplayName() {
        return Optional.ofNullable(displayName);
    }

    public ExternalDomainFederation withDisplayName(String displayName) {
        ExternalDomainFederation _x = _copy();
        _x.odataType = Util.nvl(odataType, "microsoft.graph.externalDomainFederation");
        _x.displayName = displayName;
        return _x;
    }

    @Property(name="domainName")
    @JsonIgnore
    public Optional<String> getDomainName() {
        return Optional.ofNullable(domainName);
    }

    public ExternalDomainFederation withDomainName(String domainName) {
        ExternalDomainFederation _x = _copy();
        _x.odataType = Util.nvl(odataType, "microsoft.graph.externalDomainFederation");
        _x.domainName = domainName;
        return _x;
    }

    @Property(name="issuerUri")
    @JsonIgnore
    public Optional<String> getIssuerUri() {
        return Optional.ofNullable(issuerUri);
    }

    public ExternalDomainFederation withIssuerUri(String issuerUri) {
        ExternalDomainFederation _x = _copy();
        _x.odataType = Util.nvl(odataType, "microsoft.graph.externalDomainFederation");
        _x.issuerUri = issuerUri;
        return _x;
    }

    public ExternalDomainFederation withUnmappedField(String name, Object value) {
        ExternalDomainFederation _x = _copy();
        _x.setUnmappedField(name, value);
        return _x;
    }

    @JsonAnySetter
    private void setUnmappedField(String name, Object value) {
        if (unmappedFields == null) {
            unmappedFields = new UnmappedFieldsImpl();
        }
        unmappedFields.put(name, value);
    }

    @JsonAnyGetter
    private UnmappedFieldsImpl unmappedFields() {
        return unmappedFields == null ? UnmappedFieldsImpl.EMPTY : unmappedFields;
    }

    @Override
    public UnmappedFields getUnmappedFields() {
        return unmappedFields();
    }

    @Override
    public void postInject(boolean addKeysToContextPath) {
        // do nothing;
    }

    /**
     * Returns a builder which is used to create a new
     * instance of this class (given that this class is immutable).
     *
     * @return a new Builder for this class
     */
    // Suffix used on builder factory method to differentiate the method
    // from static builder methods on superclasses
    public static Builder builderExternalDomainFederation() {
        return new Builder();
    }

    public static final class Builder {
        private String displayName;
        private String domainName;
        private String issuerUri;
        private ChangedFields changedFields = ChangedFields.EMPTY;

        Builder() {
            // prevent instantiation
        }

        public Builder displayName(String displayName) {
            this.displayName = displayName;
            this.changedFields = changedFields.add("displayName");
            return this;
        }

        public Builder domainName(String domainName) {
            this.domainName = domainName;
            this.changedFields = changedFields.add("domainName");
            return this;
        }

        public Builder issuerUri(String issuerUri) {
            this.issuerUri = issuerUri;
            this.changedFields = changedFields.add("issuerUri");
            return this;
        }

        public ExternalDomainFederation build() {
            ExternalDomainFederation _x = new ExternalDomainFederation();
            _x.contextPath = null;
            _x.unmappedFields = new UnmappedFieldsImpl();
            _x.odataType = "microsoft.graph.externalDomainFederation";
            _x.displayName = displayName;
            _x.domainName = domainName;
            _x.issuerUri = issuerUri;
            return _x;
        }
    }

    private ExternalDomainFederation _copy() {
        ExternalDomainFederation _x = new ExternalDomainFederation();
        _x.contextPath = contextPath;
        _x.unmappedFields = unmappedFields.copy();
        _x.odataType = odataType;
        _x.displayName = displayName;
        _x.domainName = domainName;
        _x.issuerUri = issuerUri;
        return _x;
    }

    @Override
    public String toString() {
        StringBuilder b = new StringBuilder();
        b.append("ExternalDomainFederation[");
        b.append("displayName=");
        b.append(this.displayName);
        b.append(", ");
        b.append("domainName=");
        b.append(this.domainName);
        b.append(", ");
        b.append("issuerUri=");
        b.append(this.issuerUri);
        b.append("]");
        b.append(",unmappedFields=");
        b.append(unmappedFields);
        b.append(",odataType=");
        b.append(odataType);
        return b.toString();
    }

}
